import { useRef, useState, useCallback, useEffect } from 'react';

function useWindowWidth() {
  var isMounted = useRef(true);
  var isSsr = typeof window === 'undefined';

  var _useState = useState(isSsr ? 0 : window.innerWidth),
      width = _useState[0],
      setWidth = _useState[1];

  var handleResize = useCallback(function () {
    if (isMounted.current) {
      setWidth(window.innerWidth);
    }
  }, [setWidth]);
  useEffect(function () {
    window.addEventListener('resize', function () {
      window.requestAnimationFrame(handleResize);
    });
    return function () {
      isMounted.current = false;
      window.removeEventListener('resize', handleResize);
    };
  }, [handleResize]);
  return width;
}

export default useWindowWidth;
//# sourceMappingURL=react-hook-use-window-width.esm.js.map
